3 ms·
Thanks, regardless of ability to parallelise it looks interesting.
by brutusborn 3y ago
Thanks, regardless of ability to parallelise it looks interesting.
- samsquire 3y agoI've changed the algorithm to not send fScore updates and treat each branch as independent. This speeds it up from 16 seconds to 320 milliseconds. I am thinking how to make the algorithm scale, by creating better and alternative program candidates in each thread.